@@ -1,4 +1,9 @@
-use crate::{opcodes::*, reader::Reader, types::errors::SendError};
+use crate::{
+    opcodes::*,
+    reader::Reader,
+    types::{errors::SendError, QueryResult},
+    writer::Writer,
+};
 use std::{
     io::{Error, Write},
     net::TcpStream,
@@ -36,6 +41,31 @@ pub fn send_internal_server_error(stream: &mut TcpStream) -> Result<(), Error> {
     Ok(())
 }
 
+pub fn send_metric_not_found(stream: &mut TcpStream) -> Result<(), Error> {
+    stream.write_all(&[OP_METRIC_NOT_FOUND])?;
+
+    Ok(())
+}
+
+pub fn send_invalid_range(stream: &mut TcpStream) -> Result<(), Error> {
+    stream.write_all(&[OP_INVALID_RANGE])?;
+
+    Ok(())
+}
+
+pub fn send_invalid_aggr_window(stream: &mut TcpStream) -> Result<(), Error> {
+    stream.write_all(&[OP_INVALID_AGGR_WINDOW])?;
+
+    Ok(())
+}
+
+pub fn send_query_result(stream: &mut TcpStream, query_result: QueryResult) -> Result<(), Error> {
+    let mut writer = Writer::new(stream);
+    writer.query_result(query_result)?;
+
+    Ok(())
+}
+
 // Receive
 
 pub fn recv_event_ack(stream: &TcpStream) -> Result<(), SendError> {
@@ -61,3 +91,8 @@ pub fn recv_query_ack(stream: &TcpStream) -> Result<(), SendError> {
         op => panic!("Received unexpected opcode: {:?}", op),
     }
 }
+
+pub fn recv_query_result(stream: &TcpStream) -> Result<QueryResult, SendError> {
+    let mut reader = Reader::new(stream);
+    reader.query_result()
+}
